@@ -2,7 +2,7 @@ package metrics
 
 import (
 	promv1 "github.com/prometheus-operator/prometheus-operator/pkg/apis/monitoring/v1"
-	"k8s.io/apimachinery/pkg/runtime"
+	utilruntime "k8s.io/apimachinery/pkg/util/runtime"
 	"sigs.k8s.io/controller-runtime/pkg/client"
 
 	"kubevirt.io/ssp-operator/internal/common"
@@ -12,37 +12,45 @@ import (
 // Define RBAC rules needed by this operand:
 // +kubebuilder:rbac:groups=monitoring.coreos.com,resources=prometheusrules,verbs=get;list;watch;create;update;patch;delete
 
+func init() {
+	utilruntime.Must(promv1.AddToScheme(common.Scheme))
+}
+
+func WatchTypes() []client.Object {
+	return []client.Object{&promv1.PrometheusRule{}}
+}
+
 type metrics struct{}
 
 func (m *metrics) Name() string {
 	return operandName
 }
 
-func (m *metrics) AddWatchTypesToScheme(scheme *runtime.Scheme) error {
-	return promv1.AddToScheme(scheme)
-}
-
 func (m *metrics) WatchTypes() []client.Object {
-	return []client.Object{&promv1.PrometheusRule{}}
+	return WatchTypes()
 }
 
 func (m *metrics) WatchClusterTypes() []client.Object {
 	return nil
 }
 
-func (m *metrics) Reconcile(request *common.Request) ([]common.ResourceStatus, error) {
+func (m *metrics) RequiredCrds() []string {
+	return []string{"prometheusrules.monitoring.coreos.com"}
+}
+
+func (m *metrics) Reconcile(request *common.Request) ([]common.ReconcileResult, error) {
 	return common.CollectResourceStatus(request,
 		reconcilePrometheusRule,
 	)
 }
 
-func (m *metrics) Cleanup(*common.Request) error {
-	return nil
+func (m *metrics) Cleanup(*common.Request) ([]common.CleanupResult, error) {
+	return nil, nil
 }
 
 var _ operands.Operand = &metrics{}
 
-func GetOperand() operands.Operand {
+func New() operands.Operand {
 	return &metrics{}
 }
 
@@ -51,7 +59,7 @@ const (
 	operandComponent = common.AppComponentMonitoring
 )
 
-func reconcilePrometheusRule(request *common.Request) (common.ResourceStatus, error) {
+func reconcilePrometheusRule(request *common.Request) (common.ReconcileResult, error) {
 	return common.CreateOrUpdate(request).
 		NamespacedResource(newPrometheusRule(request.Namespace)).
 		WithAppLabels(operandName, operandComponent).
