@@ -4,7 +4,7 @@ import (
 	"bytes"
 
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	kubevirtv1 "kubevirt.io/client-go/api/v1"
+	kubevirtv1 "kubevirt.io/client-go/apis/core/v1"
 	"kubevirt.io/client-go/log"
 
 	"kubevirt.io/ssp-operator/internal/template-validator/validation"
